@@ -264,7 +264,8 @@ void builddata(gchar *datafilename, glong &wordcount, glong &idxfilesize, glong
 		}
 		if (!worditem.word[0]) {
 			g_print("Bad word!\n");
-			return;
+			p = p2;
+			continue;
 		}
 		while (g_ascii_isspace(*p4)) {
 			p4++;
@@ -296,8 +297,8 @@ void builddata(gchar *datafilename, glong &wordcount, glong &idxfilesize, glong
 		*p='\0';
 	gchar idxfilename[256];
 	gchar dicfilename[256];
-	sprintf(idxfilename, "powerword_%s.idx", basefilename);
-	sprintf(dicfilename, "powerword_%s.dict", basefilename);
+	sprintf(idxfilename, "powerword2007_%s.idx", basefilename);
+	sprintf(dicfilename, "powerword2007_%s.dict", basefilename);
 	FILE *idxfile = fopen(idxfilename,"w");
 	FILE *dicfile = fopen(dicfilename,"w");
 
@@ -325,7 +326,7 @@ void builddata(gchar *datafilename, glong &wordcount, glong &idxfilesize, glong
 	synwordcount = array2->len;
 	if (array2->len) {
                 gchar synfilename[256];
-                sprintf(synfilename, "powerword_%s.syn", basefilename);
+                sprintf(synfilename, "powerword2007_%s.syn", basefilename);
                 FILE *synfile = fopen(synfilename,"w");
                 struct _synworditem *psynworditem;
                 gint iFrom, iTo, iThisIndex, cmpint;
@@ -444,9 +445,9 @@ void buildifo(gchar *xmlfilename, glong wordcount, glong idxfilesize, glong synw
         if (p)
                 *p='\0';
         gchar ifofilename[256];
-        sprintf(ifofilename, "powerword_%s.ifo", basefilename);
+        sprintf(ifofilename, "powerword2007_%s.ifo", basefilename);
         FILE *ifofile = fopen(ifofilename,"w");
-	gchar *content = g_strdup_printf("StarDict's dict ifo file\nversion=2.4.2\nwordcount=%ld\n%sidxfilesize=%ld\nbookname=%s\nauthor=金山软件股份公司\ndescription=Dwing破解，胡正制作。\ndate=2006.6.4\nsametypesequence=k\n", wordcount, synstr, idxfilesize, bookname);
+	gchar *content = g_strdup_printf("StarDict's dict ifo file\nversion=2.4.2\nwordcount=%ld\n%sidxfilesize=%ld\nbookname=%s\nauthor=金山软件股份公司\ndescription=Enjoy!\ndate=2006.12.23\nsametypesequence=k\n", wordcount, synstr, idxfilesize, bookname);
 	g_free(synstr);
 	fwrite(content, strlen(content), 1, ifofile);
 	g_free(content);
@@ -454,19 +455,25 @@ void buildifo(gchar *xmlfilename, glong wordcount, glong idxfilesize, glong synw
 	g_free(buffer);
 
 	gchar command[256];
-        sprintf(command, "mkdir stardict-powerword_%s-2.4.2", basefilename);
+        sprintf(command, "mkdir stardict-powerword2007_%s-2.4.2", basefilename);
         system(command);
-	sprintf(command, "mv powerword_%s.idx stardict-powerword_%s-2.4.2", basefilename, basefilename);
+	sprintf(command, "mv powerword2007_%s.idx stardict-powerword2007_%s-2.4.2", basefilename, basefilename);
 	system(command);
 	if (synwordcount) {
-		sprintf(command, "mv powerword_%s.syn stardict-powerword_%s-2.4.2", basefilename, basefilename);
+		sprintf(command, "mv powerword2007_%s.syn stardict-powerword2007_%s-2.4.2", basefilename, basefilename);
         	system(command);
 	}
-	sprintf(command, "mv powerword_%s.dict.dz stardict-powerword_%s-2.4.2", basefilename, basefilename);
+	sprintf(command, "mv powerword2007_%s.dict.dz stardict-powerword2007_%s-2.4.2", basefilename, basefilename);
         system(command);
-	sprintf(command, "mv powerword_%s.ifo stardict-powerword_%s-2.4.2", basefilename, basefilename);
+	sprintf(command, "mv powerword2007_%s.ifo stardict-powerword2007_%s-2.4.2", basefilename, basefilename);
 	system(command);
-	sprintf(command, "chmod 644 stardict-powerword_%s-2.4.2/*", basefilename);
+	sprintf(command, "chmod 644 stardict-powerword2007_%s-2.4.2/*", basefilename);
+	system(command);
+	sprintf(command, "chown root.root -R stardict-powerword2007_%s-2.4.2", basefilename);
+	system(command);
+	sprintf(command, "tar -cjvf stardict-powerword2007_%s-2.4.2.tar.bz2 stardict-powerword2007_%s-2.4.2", basefilename, basefilename);
+	system(command);
+	sprintf(command, "rm -rf stardict-powerword2007_%s-2.4.2", basefilename);
 	system(command);
 
         g_free(basefilename);
@@ -526,10 +533,6 @@ bool convert_utf(gchar *filename, gchar *utffilename)
 		system(command);
 		sprintf(command, "rm %s.bad", utffilename);
 		system(command);
-	} else if (strcmp(utffilename, "pwdecahd.da3.utf")==0) {
-		g_print("You need to edit \"affair\" and \"apparent\" manually, add end tags.\n");
-	} else if (strcmp(utffilename, "pwzeczl.da3.utf")==0) {
-		g_print("You need to edit \"construction of railways\", \"preparation\", \"vehicle\", \"details\", \"mining\" and \"discharge tube\" manually, add end tags.\n");
 	}
 	g_print("Convert over!\n");
 	return false;
